@@ -1,5 +1,5 @@
 /*  ADCD - A Diminutive CD player for Linux/GNU
-    Copyright (C) 2004-2016 Antonio Diaz Diaz.
+    Copyright (C) 2004-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ namespace {
 
 const char * const Program_name = "Adcd";
 const char * const program_name = "adcd";
-const char * const program_year = "2016";
+const char * const program_year = "2017";
 const char * invocation_name = 0;
 
 
@@ -113,8 +113,7 @@ void show_error( const char * const msg, const int errcode = 0,
   if( msg && msg[0] )
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 )
-      std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
     std::fputc( '\n', stderr );
     }
   if( help )
