@@ -1,5 +1,5 @@
 /*  ADCD - A Diminutive CD player for Linux/GNU
-    Copyright (C) 2004-2016 Antonio Diaz Diaz.
+    Copyright (C) 2004-2017 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -256,7 +256,7 @@ void set_signals()
 void Player::main_loop( CD & cd )
   {
   cd_ptr = &cd;
-  srand( time(0) );
+  std::srand( std::time( 0 ) );
   initialize_ncurses();
   show_panel(); show_data( cd );
   set_signals();
